@@ -46,7 +46,7 @@ if (process.env.HEADLAMP_RUN_SCRIPT) {
 _dotenv.default.config({
   path: _path.default.join(process.resourcesPath, '.env')
 });
-const isDev = process.env.ELECTRON_DEV || false;
+const isDev = !!process.env.ELECTRON_DEV;
 let frontendPath = '';
 if (isDev) {
   frontendPath = _path.default.resolve('..', 'frontend', 'build', 'index.html');
@@ -1171,7 +1171,7 @@ function adjustZoom(delta) {
   const newZoom = clampZoom(cachedZoom + delta);
   setZoom(newZoom);
 }
-function startElecron() {
+function startElectron() {
   console.info('App starting...');
   let appVersion;
   if (isDev && process.env.HEADLAMP_APP_VERSION) {
@@ -1593,6 +1593,6 @@ if (isHeadlessMode) {
   });
 } else {
   if (!isRunningScript) {
-    startElecron();
+    startElectron();
   }
 }
\ No newline at end of file
